summaryrefslogtreecommitdiff
path: root/sd/qa/unit/PNGExportTests.cxx
diff options
context:
space:
mode:
authorXisco Fauli <xiscofauli@libreoffice.org>2023-10-20 10:28:50 +0200
committerXisco Fauli <xiscofauli@libreoffice.org>2023-10-20 12:26:01 +0200
commitb34132256c1e9ebbf0cc82a14f4da7335574a887 (patch)
treeac276ce452060a6ac39f00b780849d947a7d7169 /sd/qa/unit/PNGExportTests.cxx
parent367891c40ec683767d91ddeaf566c396f22b9035 (diff)
CppunitTest_sd_png_export_tests: relax test even more
I misread https://gerrit.libreoffice.org/c/core/+/158181/3#message-f54ed5a8dcf1d68fea73ace5ff9851d3d5fe5a2f Change-Id: I31523af088f8fa83f43a8a49e449d27b0f230149 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/158229 Tested-by: Jenkins Reviewed-by: Xisco Fauli <xiscofauli@libreoffice.org>
Diffstat (limited to 'sd/qa/unit/PNGExportTests.cxx')
-rw-r--r--sd/qa/unit/PNGExportTests.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sd/qa/unit/PNGExportTests.cxx b/sd/qa/unit/PNGExportTests.cxx
index 6c6d13a8a942..c141c0ddeeb0 100644
--- a/sd/qa/unit/PNGExportTests.cxx
+++ b/sd/qa/unit/PNGExportTests.cxx
@@ -296,9 +296,9 @@ CPPUNIT_TEST_FIXTURE(SdPNGExportTest, testTdf156808)
}
// Without the fix in place, this test would have failed with
// - Expected greater than: 9300
// - Actual : 0
- CPPUNIT_ASSERT_GREATER(9300, nBlackCount);
+ CPPUNIT_ASSERT_GREATER(9000, nBlackCount);
}
CPPUNIT_TEST_FIXTURE(SdPNGExportTest, testTdf157636)
@@ -296,9 +296,9 @@ CPPUNIT_TEST_FIXTURE(SdPNGExportTest, testTdf156808)
}
// Without the fix in place, this test would have failed with
- // - Expected greater than: 9300
+ // - Expected greater than: 9000
// - Actual : 0